Index: trunk/admin/config.default.php
===================================================================
--- trunk/admin/config.php.example	(revision 647)
+++ trunk/admin/config.default.php	(revision 902)
@@ -1,38 +1,34 @@
 <?php
 
 // this is an example only
 // write your own config and name it as config.php
 
 // detected by browser
-// $lang = 'en-us';
+// $config['lang'] = 'en-us';
 
-$charset = "UTF-8";
+$config['charset'] = "UTF-8";
 
-// developers only
-$show_todo_strings = false;
+// translators only
+$config['show_todo_strings'] = false;
 
 // width of graph for free or usage blocks
-$usage_graph_width = 120;
-// do not define both with
-// $free_graph_width = 120;
+$config['percent_graph_width'] = 120;
+$config['percent_graph_type'] = 'used'; // either 'used' or 'free'
 
 // only enable if you have password protection for admin page
 // enabling this option will cause user to eval() whatever code they want
-$enable_eval = false;
+$config['enable_eval'] = false;
 
-// this function is detected by xcache.tpl.php, and enabled if function_exists
 // this ob filter is applied for the cache list, not the whole page
-function ob_filter_path_nicer($o)
+$config['path_nicer'] = 'ob_filter_path_nicer_default';
+
+/*
+function custom_ob_filter_path_nicer($list_html)
 {
-	$sep = DIRECTORY_SEPARATOR;
-	$d = $_SERVER['DOCUMENT_ROOT'];
-	$o = str_replace($d,  "{DOCROOT}" . (substr($d, -1) == $sep ? $sep : ""), $o);
-	$xcachedir = realpath(dirname(__FILE__) . "$sep..$sep");
-	$o = str_replace($xcachedir . $sep, "{XCache}$sep", $o);
-	if ($sep == '/') {
-		$o = str_replace("/home/", "{H}/", $o);
-	}
-	return $o;
+	$list_html = ob_filter_path_nicer_default($list_html); // this function is from common.php
+	return $list_html;
 }
+$config['path_nicer'] = 'custom_ob_filter_path_nicer';
+*/
 
 // you can simply let xcache to do the http auth
@@ -40,4 +36,5 @@
 // {{{ home made login example
 // this is an example only, it's won't work for you without your implemention.
+/*
 function check_admin_and_by_pass_xcache_http_auth()
 {
@@ -63,7 +60,12 @@
 }
 
-// uncomment:
-// check_admin_and_by_pass_xcache_http_auth();
+check_admin_and_by_pass_xcache_http_auth();
+*/
 // }}}
 
+/* by pass XCache http auth
+$_SERVER["PHP_AUTH_USER"] = "moo";
+$_SERVER["PHP_AUTH_PW"] = "your-xcache-password";
+*/
+
 ?>
@@ -1,38 +1,34 @@
 <?php
 
-// this is an example only
-// write your own config and name it as config.php
+// this is default config, DO NOT modify this file
+// copy this file and write your own config and name it as config.php
 
 // detected by browser
